@@ -80,7 +80,6 @@ class GPXXMLSyntaxException(GPXException):
         self.__cause__ = original_exception
 
 class GPXWaypoint(mod_geo.Location):
-	
     time = None
     name = None
     description = None
@@ -153,7 +152,6 @@ class GPXWaypoint(mod_geo.Location):
                 'comment', 'horizontal_dilution', 'vertical_dilution', 'position_dilution')
 
 class GPXRoute:
-
     def __init__(self, name=None, description=None, number=None):
         self.name = name
         self.description = description
@@ -220,7 +218,6 @@ class GPXRoute:
         return mod_utils.hash_object(self, 'name', 'description', 'number', 'points')
 
 class GPXRoutePoint(mod_geo.Location):
-
     def __init__(self, latitude, longitude, elevation=None, time=None, name=None,
             description=None, symbol=None, type=None, comment=None,
             horizontal_dilution=None, vertical_dilution=None,
@@ -273,7 +270,6 @@ class GPXRoutePoint(mod_geo.Location):
                 'horizontal_dilution', 'vertical_dilution', 'position_dilution')
 
 class GPXTrackPoint(mod_geo.Location):
-
     def __init__(self, latitude, longitude, elevation=None, time=None, symbol=None, comment=None,
             horizontal_dilution=None, vertical_dilution=None, position_dilution=None, speed=None,
             name=None):
@@ -364,7 +360,6 @@ class GPXTrackPoint(mod_geo.Location):
                 'horizontal_dilution', 'vertical_dilution', 'position_dilution', 'speed')
 
 class GPXTrack:
-
     def __init__(self, name=None, description=None, number=None):
         self.name = name
         self.description = description
@@ -372,6 +367,13 @@ class GPXTrack:
 
         self.segments = []
 
+    def simplify(self, max_distance=None):
+        """
+        Simplify using the Ramer-Douglas-Peucker algorithm: http://en.wikipedia.org/wiki/Ramer-Douglas-Peucker_algorithm
+        """
+        for segment in self.segments:
+            segment.simplify(max_distance=max_distance)
+
     def remove_time(self):
         for segment in self.segments:
             segment.remove_time()
@@ -676,10 +678,44 @@ class GPXTrack:
         return mod_utils.hash_object(self, 'name', 'description', 'number', 'segments')
 
 class GPXTrackSegment:
-
     def __init__(self, points=None):
         self.points = points if points else []
 
+    def simplify(self, max_distance=None):
+        """
+        Simplify using the Ramer-Douglas-Peucker algorithm: http://en.wikipedia.org/wiki/Ramer-Douglas-Peucker_algorithm
+        """
+        if len(self.points) <= 2:
+            return
+
+        if not max_distance:
+            max_distance = 10
+
+        result = [self.points[0]]
+
+        next_point = self._find_next_simplified_point(0, max_distance)
+        if next_point != None:
+            result.append(self.points[next_point])
+            while next_point != None:
+                next_point = self._find_next_simplified_point(next_point, max_distance)
+                if next_point != None:
+                    result.append(self.points[next_point])
+
+        if not (self.points[-1] in result):
+            result.append(self.points[-1])
+
+        self.points = result
+
+    def _find_next_simplified_point(self, pos, max_distance):
+        for candidate in range(pos + 1, len(self.points) - 1):
+            for i in range(pos + 1, candidate):
+                d = mod_geo.distance_from_line(self.points[i],
+                                               self.points[pos],
+                                               self.points[candidate])
+                if d > max_distance:
+                    return candidate - 1
+        return None
+
     def remove_time(self):
         for track_point in self.points:
             track_point.remove_time()
@@ -903,7 +939,9 @@ class GPXTrackSegment:
 
         assert len(interval) == len(distances)
 
-        return list(map(lambda distance : distance / from_start_to_end, distances))
+        return list(map(
+                lambda distance : (distance / from_start_to_end) if from_start_to_end else 0,
+                distances))
 
     def get_duration(self):
         """ Duration in seconds """
@@ -1172,7 +1210,6 @@ class GPXTrackSegment:
         return mod_copy.deepcopy(self)
 
 class GPX:
-
     def __init__(self, waypoints=None, routes=None, tracks=None):
         if waypoints: self.waypoints = waypoints
         else: self.waypoints = []
@@ -1191,12 +1228,20 @@ class GPX:
         self.urlname = None
         self.time = None
         self.keywords = None
+        self.creator = None
 
         self.min_latitude = None
         self.max_latitude = None
         self.min_longitude = None
         self.max_longitude = None
 
+    def simplify(self, max_distance=None):
+        """
+        Simplify using the Ramer-Douglas-Peucker algorithm: http://en.wikipedia.org/wiki/Ramer-Douglas-Peucker_algorithm
+        """
+        for track in self.tracks:
+            track.simplify(max_distance=max_distance)
+
     def remove_time(self):
         """ Will remove time metadata. """
         for track in self.tracks:
@@ -1675,7 +1720,9 @@ class GPX:
                 'xmlns:xsi': 'http://www.w3.org/2001/XMLSchema-instance',
                 'xmlns': 'http://www.topografix.com/GPX/1/0',
                 'xsi:schemaLocation': 'http://www.topografix.com/GPX/1/0 http://www.topografix.com/GPX/1/0/gpx.xsd',
-       }
+        }
+        if self.creator:
+            xml_attributes['creator'] = self.creator
 
         return '<?xml version="1.0" encoding="UTF-8"?>\n' + mod_utils.to_xml('gpx', attributes=xml_attributes, content=content).strip()
 
