@@ -26,6 +26,7 @@ import xml.dom.minidom as mod_minidom
 try:
     import lxml.etree as mod_etree
 except:
+    mod_etree = None
     pass # LXML not available
 
 from . import gpx as mod_gpx
@@ -90,6 +91,8 @@ class LXMLParser:
     """
 
     def __init__(self, xml):
+        assert mod_etree
+
         if mod_utils.PYTHON_VERSION[0] == '3':
             # In python 3 all strings are unicode and for some reason lxml 
             # don't like unicode strings with XMLs declared as UTF-8:
@@ -218,6 +221,8 @@ class GPXParser:
         node = self.xml_parser.get_first_child(name='gpx')
         if node is None:
             raise mod_gpx.GPXException('Document must have a `gpx` root node.')
+        if self.xml_parser.get_node_attribute(node, "creator"):
+          self.gpx.creator = self.xml_parser.get_node_attribute(node, "creator")
 
         for node in self.xml_parser.get_children(node):
             node_name = self.xml_parser.get_node_name(node)
